==> SomatiCA_1.6.0.tar.gz: SomatiCA/R/SomatiCAFormat.R <==
# Method for reading from a file:
setMethod("SomatiCAFormat", "character",
   function(data, missing=TRUE, verbose=TRUE, ...) 
   {
     #### Created by Mengjie Chen, Jan 2013
        x <- read.table(data, ...)
        data <- as.data.frame(x)
        ncols <- ncol(data)
        if (ncols != 7)
          stop("7 columns are expected from the input file! Check the manual!")
        colnames(data) <- c("seqnames", "start", "zygosity", "tCount", "LAF", "tCountN", "germLAF") 
        if (missing == TRUE) {
           if (verbose == TRUE)  message("Checking for missingness...")
              flagNA <- apply(data, 1, function(x){
                return(any(is.na(x)))
              })  
           if (any(flagNA)) {
                data <- data[!flagNA, ]
                message("Markers with missing values have been removed.")
           } 
        }	 
        myNewData <- GRanges(seqnames=data$seqnames, 
                             ranges=IRanges(start=data$start, width=1),
                             zygosity=as.character(data$zygosity),
                             tCount=data$tCount, LAF=data$LAF,
                             tCountN=data$tCountN,
                             germLAF=data$germLAF)
        callGeneric(data=myNewData, missing=missing, verbose=verbose)
      }
)


setMethod("SomatiCAFormat", "data.frame",
          function(data, missing=TRUE, verbose=TRUE, ...) 
          {
              #### Created by Mengjie Chen, Jan 2013
              if (missing == TRUE) {
              if (verbose == TRUE)  message("Checking for missingness...")
              flagNA <- apply(data, 1, function(x){
                return(any(is.na(x)))
              })  
              if (any(flagNA)) {
                data <- data[!flagNA, ]
                message("Markers with missing values have been removed.")
              } 
            }   
             myNewData <- GRanges(seqnames=data$seqnames, 
                                 ranges=IRanges(start=data$start, width=1),
                                 zygosity=as.character(data$zygosity),
                                 tCount=data$tCount, LAF=data$LAF,
                                 tCountN=data$tCountN,
                                 germLAF=data$germLAF)
            callGeneric(data=myNewData, missing=missing, verbose=verbose)
          }
)

# Method for reading from a GRanges in R:
setMethod("SomatiCAFormat", "GRanges",
      function(data, missing=TRUE, verbose=TRUE, ...) 
      {
         if(unique(width(data)) != 1)
            stop("The width of range should be 1.")
         meta <- elementMetadata(data)
         if (ncol(meta) != 5)
            stop("5 columns are expected from the Meta data!")
         data <- as.data.frame(data, stringsAsFactors=FALSE)
         data$zygosity <- as.character(data$zygosity)         
         if (!any(grep("het", data$zygosity)))
            stop("No heterozygous sites in column zygosity!")
         if (!is.numeric(data$tCount) | !is.numeric(data$LAF)| !is.numeric(data$tCountN) |!is.numeric(data$germLAF)) 
            stop("Location, read counts and LAF must be numeric.")
         if(any(data$tCount < 0, na.rm = TRUE) | any(data$tCountN < 0, na.rm = TRUE))
            stop("Negative value detected in read counts.")
         epsi <- 0.001
         if(any(data$LAF > 0.5 + epsi, na.rm = TRUE) | any(data$germLAF > 0.5 + epsi, na.rm = TRUE))
           stop("Unexpected value (> 0.5) in LAF.") 
         myNewData <- GRanges(seqnames=data$seqnames, 
                              ranges=IRanges(start=data$start, width=1),
                              zygosity=as.character(data$zygosity),
                              tCount=data$tCount, LAF=data$LAF,
                              tCountN=data$tCountN,
                              germLAF=data$germLAF)  
         return(myNewData)
      }
)

==> SomatiCA_2.2.1.tar.gz: SomatiCA/R/SomatiCAFormat.R <==
# Method for reading from a file:
setMethod("SomatiCAFormat", "character",
   function(data, missing=TRUE, verbose=TRUE, ...) 
   {
     #### Created by Mengjie Chen, Jan 2013
        x <- read.table(data, ...)
        data <- as.data.frame(x, stringsAsFactors=FALSE)
        ncols <- ncol(data)
        if (ncols != 7)
          stop("7 columns are expected from the input file! Check the manual!")
        colnames(data) <- c("seqnames", "start", "zygosity", "tCount", "LAF", "tCountN", "germLAF") 
        if (missing == TRUE) {
           if (verbose == TRUE)  message("Checking for missingness...")
              flagNA <- apply(data, 1, function(x){
                return(any(is.na(x)))
              })  
           if (any(flagNA)) {
                data <- data[!flagNA, ]
                message("Markers with missing values have been removed.")
           } 
        }	 
        myNewData <- GRanges(seqnames=data$seqnames, 
                             ranges=IRanges(start=data$start, width=1),
                             zygosity=as.character(data$zygosity),
                             tCount=data$tCount, LAF=data$LAF,
                             tCountN=data$tCountN,
                             germLAF=data$germLAF)
        callGeneric(data=myNewData, missing=missing, verbose=verbose)
      }
)


setMethod("SomatiCAFormat", "data.frame",
          function(data, missing=TRUE, verbose=TRUE) 
          {
              #### Created by Mengjie Chen, Jan 2013
              if (missing == TRUE) {
              if (verbose == TRUE)  message("Checking for missingness...")
              flagNA <- apply(data, 1, function(x){
                return(any(is.na(x)))
              })  
              if (any(flagNA)) {
                data <- data[!flagNA, ]
                message("Markers with missing values have been removed.")
              } 
            }   
             myNewData <- GRanges(seqnames=data$seqnames, 
                                 ranges=IRanges(start=data$start, width=1),
                                 zygosity=as.character(data$zygosity),
                                 tCount=data$tCount, LAF=data$LAF,
                                 tCountN=data$tCountN,
                                 germLAF=data$germLAF)
            callGeneric(data=myNewData, missing=missing, verbose=verbose)
          }
)

# Method for reading from a GRanges in R:
setMethod("SomatiCAFormat", "GRanges",
      function(data, missing=TRUE, verbose=TRUE) 
      {
         if(unique(width(data)) != 1)
            stop("The width of range should be 1.")
         meta <- elementMetadata(data)
         if (ncol(meta) != 5)
            stop("5 columns are expected from the Meta data!")
         data <- as.data.frame(data, stringsAsFactors=FALSE)
         data$zygosity <- as.character(data$zygosity)         
         if (!any(grep("het", data$zygosity)))
            stop("No heterozygous sites in column zygosity!")
         if (!is.numeric(data$tCount) | !is.numeric(data$LAF)| !is.numeric(data$tCountN) |!is.numeric(data$germLAF)) 
            stop("Location, read counts and LAF must be numeric.")
         if(any(data$tCount < 0, na.rm = TRUE) | any(data$tCountN < 0, na.rm = TRUE))
            stop("Negative value detected in read counts.")
         epsi <- 0.001
         if(any(data$LAF > 0.5 + epsi, na.rm = TRUE) | any(data$germLAF > 0.5 + epsi, na.rm = TRUE))
           stop("Unexpected value (> 0.5) in LAF.") 
         myNewData <- GRanges(seqnames=data$seqnames, 
                              ranges=IRanges(start=data$start, width=1),
                              zygosity=as.character(data$zygosity),
                              tCount=data$tCount, LAF=data$LAF,
                              tCountN=data$tCountN,
                              germLAF=data$germLAF)  
         return(myNewData)
      }
)
